# -*- coding: utf-8 -*-
import setuptools
from distutils.core import setup

setup(
    name='IntexfyLibs',
    version='0.0.6',
    py_modules=['IntexfyLibs'],
    author='Heitor Tancredo',
    author_email='heitor@intexfy.com',
    keywords='Intexfy Libs',
    description='Package with intexfy libs',
)
